==> glx.ui-1.8.32.tgz: package/components/attestationsListSem/attestationsListSem.ts <==
import { Component, EventEmitter, Input, NgModule, OnInit, Output, ViewChild } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';


import { DataTable, DataTableModule } from 'primeng/components/datatable/datatable';
import { DropdownModule } from 'primeng/components/dropdown/dropdown';
import { OverlayPanelModule } from 'primeng/components/overlaypanel/overlaypanel';
import { SharedModule } from 'primeng/components/common/shared';

import { ProfileViewerModule } from '../profileViewer/profileViewer';
import { LoadingBannerModule } from '../loadingBanner/loadingBanner';

import { GlxSharedModule } from '../kernel/shared.module';

/**
 * Фильтр по аттестациям
 */
class Filter {
    faculty: number;
    group: number;
    year: number;
    semester: number;
    fullname: string;
    book_num: string;

    first = 0;
    rows = 20;
    sortField = 'fullname';
    sortOrder = 1;

    constructor() {
        this.year = this.DefaultYear;
        this.semester = this.DefaultSemester;
    }

    get DefaultYear() {
        return new Date().getFullYear();
    }

    get DefaultSemester() {
        const date = new Date();

        if ([2, 3, 4, 5].includes(date.getMonth() + 1)) {
            return 2;
        } else {
            return 1;
        }
    }
}

/**
 * Поиск сотрудников с детальным просмотром профиля
 */
@Component({
    selector: 'glx-attestations-list-sem',
    styleUrls: ['./attestationsListSem.scss'],
    templateUrl: './attestationsListSem.html'
})

export class AttestationsListSem implements OnInit {
    /**
     * Данные для отображения в таблице
     */
    @Input() data: any = {};
    /**
     * Справочники для фильтров
     * @type {{}}
     */
    @Input() catalog: any = {};
    /**
     * Показать индикатор загрузки данных
     * @type {boolean}
     */
    @Input() loading: boolean = false;
    /**
     * Задержка поиска для общего фильтра
     * @type {number}
     */
    @Input() filterDelay: number = 1000;
    /**
     * Фильтр
     * @type {Filter}
     */
    @Input() filter: Filter = new Filter();
    /**
     * Надпись на глобальном фильтре
     * @type {string}
     */
    @Input() globalFilterPlaceholder: string = 'Поиск...';
    /**
     * Событие фильтрации. Необходимо получить новые данные сервера
     * @type {EventEmitter<any>}
     */
    @Output() onFilter: EventEmitter<any> = new EventEmitter();
    /**
     * Событий просмотра профиля. Необходимо получить профиль пользователя с сервера
     * @type {EventEmitter<any>}
     */
    @Output() onViewProfile: EventEmitter<any> = new EventEmitter();
    @Output() onViewAttestation: EventEmitter<any> = new EventEmitter();
    @Output() onViewFull: EventEmitter<any> = new EventEmitter();
    @Output() onDownloadExcel: EventEmitter<any> = new EventEmitter();

    /**
     * PrimeNG DataTable
     */
    @ViewChild('dt') datatable: DataTable;


    /**
     * Конструктор
     * @param {Router} router
     * @param {ActivatedRoute} route
     * @param {Renderer2} renderer
     */
    constructor() {
    }

    /**
     * Проверка префильтров
     */
    ngOnInit() {
        if (!this.filter || this.filter === {}) {
            this.filter = new Filter();
        }
        if (!this.filter.year || this.filter.year === 0) {
            this.filter.year = this.filter.DefaultYear;
        }
        if (!this.filter.semester || this.filter.semester === 0) {
            this.filter.semester = this.filter.DefaultSemester;
        }
    }

    /**
     * Очистить фильтр
     */
    clearFilter() {
        this.filter = new Filter();
        this.datatable.reset();
        this.datatable._filter();
    }

    /**
     * Установка и применение фильтра
     * @param name
     * @param value
     */
    setFilter(name, value) {
        this.datatable.filter(value, name, 'any');
    }

    /**
     * Событие для ленивой загрузки. Вызывается при инициализации и фильтрации
     * @param event
     */
    loadItemsLazy(event: any) {
        this.filter.first = event.first;
        this.filter.rows = event.rows;
        this.filter.sortField = event.sortField;
        this.filter.sortOrder = event.sortOrder;
        this.onFilter.emit(this.filter);
    }

    /**
     * Собатие показа профиля в слайдере
     * @param id
     */
    showProfile($event, id) {
        this.onViewProfile.emit(id);
        $event.stopPropagation();
    }

    /**
     * Одиночный щелчок по строке устанавливает ID профиля для возможного открытия
     * @param event
     */
    onRowClick(event) {
        this.onViewFull.emit(event.data);
    }

    showAttestation($event, data) {
        this.onViewAttestation.emit(data);
        $event.stopPropagation();
    }

    exportData() {
        this.onDownloadExcel.emit({filter: this.datatable.createLazyLoadMetadata()});
    }
}

@NgModule({
    imports: [
        CommonModule,
        FormsModule,
        SharedModule,
        GlxSharedModule,
        DataTableModule,
        DropdownModule,
        OverlayPanelModule,
        ProfileViewerModule,
        LoadingBannerModule
    ],
    exports: [AttestationsListSem],
    declarations: [AttestationsListSem]
})

export class AttestationsListSemModule {
}

==> glx.ui-1.9.3.tgz: package/components/attestationsListSem/attestationsListSem.ts <==
import { Component, EventEmitter, Input, NgModule, OnInit, Output, ViewChild } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';


import { DataTable, DataTableModule } from 'primeng/components/datatable/datatable';
import { DropdownModule } from 'primeng/components/dropdown/dropdown';
import { OverlayPanelModule } from 'primeng/components/overlaypanel/overlaypanel';
import { SharedModule } from 'primeng/components/common/shared';

import { ProfileViewerModule } from '../profileViewer/profileViewer';
import { LoadingBannerModule } from '../loadingBanner/loadingBanner';

import { GlxSharedModule } from '../kernel/shared.module';

/**
 * Фильтр по аттестациям
 */
class Filter {
    faculty: number;
    group: number;
    year: number;
    semester: number;
    fullname: string;
    book_num: string;

    first = 0;
    rows = 20;
    sortField = 'fullname';
    sortOrder = 1;

    constructor() {
        this.year = this.DefaultYear;
        this.semester = this.DefaultSemester;
    }

    get DefaultYear() {
        return new Date().getFullYear();
    }

    get DefaultSemester() {
        const date = new Date();

        if ([2, 3, 4, 5].includes(date.getMonth() + 1)) {
            return 2;
        } else {
            return 1;
        }
    }
}

/**
 * Поиск сотрудников с детальным просмотром профиля
 */
@Component({
    selector: 'glx-attestations-list-sem',
    styleUrls: ['./attestationsListSem.scss'],
    templateUrl: './attestationsListSem.html'
})

export class AttestationsListSem implements OnInit {
    /**
     * Данные для отображения в таблице
     */
    @Input() data: any = {};
    /**
     * Справочники для фильтров
     * @type {{}}
     */
    @Input() catalog: any = {};
    /**
     * Показать индикатор загрузки данных
     * @type {boolean}
     */
    @Input() loading: boolean = false;
    /**
     * Задержка поиска для общего фильтра
     * @type {number}
     */
    @Input() filterDelay: number = 1000;
    /**
     * Фильтр
     * @type {Filter}
     */
    @Input() filter: Filter = new Filter();
    /**
     * Надпись на глобальном фильтре
     * @type {string}
     */
    @Input() globalFilterPlaceholder: string = 'Поиск...';
    /**
     * Событие фильтрации. Необходимо получить новые данные сервера
     * @type {EventEmitter<any>}
     */
    @Output() onFilter: EventEmitter<any> = new EventEmitter();
    /**
     * Событий просмотра профиля. Необходимо получить профиль пользователя с сервера
     * @type {EventEmitter<any>}
     */
    @Output() onViewProfile: EventEmitter<any> = new EventEmitter();
    @Output() onViewAttestation: EventEmitter<any> = new EventEmitter();
    @Output() onViewFull: EventEmitter<any> = new EventEmitter();
    @Output() onDownloadExcel: EventEmitter<any> = new EventEmitter();

    /**
     * PrimeNG DataTable
     */
    @ViewChild('dt') datatable: DataTable;


    /**
     * Конструктор
     * @param {Router} router
     * @param {ActivatedRoute} route
     * @param {Renderer2} renderer
     */
    constructor() {
    }

    /**
     * Проверка префильтров
     */
    ngOnInit() {
        if (!this.filter || !this.filter.rows) {
            this.filter = new Filter();
        }
        if (!this.filter.year || this.filter.year === 0) {
            this.filter.year = this.filter.DefaultYear;
        }
        if (!this.filter.semester || this.filter.semester === 0) {
            this.filter.semester = this.filter.DefaultSemester;
        }
    }

    /**
     * Очистить фильтр
     */
    clearFilter() {
        this.filter = new Filter();
        this.datatable.reset();
        this.datatable._filter();
    }

    /**
     * Установка и применение фильтра
     * @param name
     * @param value
     */
    setFilter(name, value) {
        this.datatable.filter(value, name, 'any');
    }

    /**
     * Событие для ленивой загрузки. Вызывается при инициализации и фильтрации
     * @param event
     */
    loadItemsLazy(event: any) {
        this.filter.first = event.first;
        this.filter.rows = event.rows;
        this.filter.sortField = event.sortField;
        this.filter.sortOrder = event.sortOrder;
        this.onFilter.emit(this.filter);
    }

    /**
     * Собатие показа профиля в слайдере
     * @param id
     */
    showProfile($event, id) {
        this.onViewProfile.emit(id);
        $event.stopPropagation();
    }

    /**
     * Одиночный щелчок по строке устанавливает ID профиля для возможного открытия
     * @param event
     */
    onRowClick(event) {
        this.onViewFull.emit(event.data);
    }

    showAttestation($event, data) {
        this.onViewAttestation.emit(data);
        $event.stopPropagation();
    }

    exportData() {
        this.onDownloadExcel.emit({filter: this.datatable.createLazyLoadMetadata()});
    }
}

@NgModule({
    imports: [
        CommonModule,
        FormsModule,
        SharedModule,
        GlxSharedModule,
        DataTableModule,
        DropdownModule,
        OverlayPanelModule,
        ProfileViewerModule,
        LoadingBannerModule
    ],
    exports: [AttestationsListSem],
    declarations: [AttestationsListSem]
})

export class AttestationsListSemModule {
}
